@@ -1,11 +1,14 @@
 import json
 
 
+
+
 class RiskSignal:
     def __init__(self):
-
+        
         self.__risk_code = None  # type: str
         self.__risk_reason = None  # type: str
+        
 
     @property
     def risk_code(self):
@@ -17,7 +20,6 @@ class RiskSignal:
     @risk_code.setter
     def risk_code(self, value):
         self.__risk_code = value
-
     @property
     def risk_reason(self):
         """
@@ -29,18 +31,22 @@ class RiskSignal:
     def risk_reason(self, value):
         self.__risk_reason = value
 
+
+    
+
     def to_ams_dict(self):
         params = dict()
         if hasattr(self, "risk_code") and self.risk_code is not None:
-            params["riskCode"] = self.risk_code
+            params['riskCode'] = self.risk_code
         if hasattr(self, "risk_reason") and self.risk_reason is not None:
-            params["riskReason"] = self.risk_reason
+            params['riskReason'] = self.risk_reason
         return params
 
+
     def parse_rsp_body(self, response_body):
-        if isinstance(response_body, str):
+        if isinstance(response_body, str): 
             response_body = json.loads(response_body)
-        if "riskCode" in response_body:
-            self.__risk_code = response_body["riskCode"]
-        if "riskReason" in response_body:
-            self.__risk_reason = response_body["riskReason"]
+        if 'riskCode' in response_body:
+            self.__risk_code = response_body['riskCode']
+        if 'riskReason' in response_body:
+            self.__risk_reason = response_body['riskReason']
